@@ -1,11 +1,13 @@
 package WWW::Contact::Base;
 
-use vars qw/$VERSION $AUTHORITY/;
 use Moose;
 use Moose::Util::TypeConstraints;
-use WWW::Mechanize;
+use Carp qw/croak/;
 use Data::Dumper;
 
+our $VERSION   = '0.02';
+our $AUTHORITY = 'cpan:FAYLAND';
+
 my $sub_verbose = sub {
     my $msg = shift;
     $msg =~ s/\s+$//;
@@ -25,12 +27,16 @@ coerce 'Verbose'
     };
 
 has 'verbose' => ( is => 'rw', isa => 'Verbose', coerce => 1, default => 0 );
+has 'ua_class' => ( is => 'rw', isa => 'Str', default => 'WWW::Mechanize' );
 has 'ua' => (
     is => 'rw',
-    isa => 'WWW::Mechanize',
+    isa => 'Object',
     lazy => 1,
     default => sub {
-        WWW::Mechanize->new(
+        my $class = (shift)->ua_class;
+        eval "use $class";
+        croak $@ if ($@);
+        $class->new(
             agent       => 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)',
             cookie_jar  => {},
             stack_depth => 1,
@@ -142,10 +148,15 @@ This module is mainly for you to write your own WWW::Contact::* (and used in my
 
 =item ua
 
-an instance of WWW::Mechanize
+an instance of L<WWW::Mechanize>
 
     $self->ua->get('http://www.google.com');
 
+If u want to use WWW::Mechanize::* instead of WWW::Mechanize, try
+
+    extends 'WWW::Contact::Base';
+    has '+ua_class' => ( default => 'WWW::Mechanize::GZip' );
+
 =item verbose
 
 turn on debug, default is off
@@ -187,7 +198,7 @@ a wrapper of $self->ua->submit_form, with $resp->is_success check
 
 =head1 SEE ALSO
 
-L<WWW::Contact>, L<WWW::Mechanize::GZip>
+L<WWW::Contact>, L<WWW::Mechanize>, L<Moose>
 
 =head1 AUTHOR
 
